## ----preliminary, echo=FALSE, out=FALSE----------------------------------
library(plgraphics) ##, lib="/u/stahel/R/regdevelop/pkg/plgraphics.Rcheck")
options(warn=1)
knitr::opts_chunk$set(fig.width=8, fig.height=6)

## ----plyx----------------------------------------------------------------
plyx(Sepal.Width~Sepal.Length, data=iris, smooth=FALSE)

## ----plyx_pchar----------------------------------------------------------
plyx(Sepal.Width~Sepal.Length, data=iris, 
     psize=Petal.Length^2, pcol=Species, pch=Species, cex=1.5)

## ----plyx_smooth, fig.width=8, fig.height=4------------------------------
plmframes(1,2, mar=c(3,3,1,1))
plyx(Sepal.Width~Sepal.Length, data=iris, smooth.col="red")

plyx(Sepal.Width~Sepal.Length, data=iris, smooth.group=Species,
     pcol=Species)

## ----plyx_group, fig.width=8, fig.height=7.5-----------------------------
plmframes(2,2)
plyx(Sepal.Width~Sepal.Length, data=iris, group=Species)

## ----innerrange, fig.width=7, fig.height=3-------------------------------
data(d.blast)
dd <- d.blast
dd$distance[2] <- 200

plmframes(1,3, mar=c(3,3,1,1))

plyx( tremor~distance, data=dd, innerrange=FALSE)
plyx( tremor~distance, data=dd)
plyx( tremor~distance, data=dd, innerrange.factor=5)

## ----plyx-multipley------------------------------------------------------
plyx(1:40, EuStockMarkets[1:40,], type="b")

## ----plyx-time-----------------------------------------------------------
  data(d.river)
  plyx(T+O2+ra+Q~date, data=d.river, 
       subset=date<as.Date("2010-03-31")&hour==14, 
       smooth.par=0.5, smooth.xtrim=0.03, smooth.lty=1, sub="river data")

## ----plyx-multiplex, fig.width=8, fig.height=4---------------------------
plmframes(1,2, mar=c(3,3,3,1))
plyx(Sepal.Width~Sepal.Length+Petal.Length, data=iris, 
     smooth.group=Species, pcol=Species)

## ----markextremes, fig.width=8, fig.height=4-----------------------------
plmframes(1,2, mar=c(3,3,3,1))

plyx(Sepal.Width~Sepal.Length, data=iris[1:50,], smooth=F, 
     markextremes=0.1, cex=0.7)
## different proportions marked in different margins:
plyx(Sepal.Width~Sepal.Length, data=iris[1:50,], smooth=F, 
     markextremes=list(0,c(0.02,0.2)), cex=0.7)  

## ----mboxes--------------------------------------------------------------
plmframes()  ## reset to just 1 figure per plot
## plyx(Sepal.Width~Species, data=iris)  ## -- or --
plmboxes(Petal.Length~Species, data=iris)

## ----censored------------------------------------------------------------
require("survival")
data(lung, package="survival")
plmframes(1,2,mar=c(3,3,1,1))
plyx(Surv(time,status) ~ age+wt.loss, data=lung, pcol=sex)

## ----plmatrix,  fig.width=10, fig.height=10------------------------------
plmatrix(iris, smooth.group=Species, pcol=Species)

## ----plmatrix_sub--------------------------------------------------------
plmatrix(~Petal.Length+Petal.Width, ~Sepal.Length+Sepal.Width, data=iris, 
         smooth.group=Species, pcol=Species)

## ----plotregr,  fig.width=8, fig.height=7.5------------------------------
data(d.blast)
rr <- 
  lm(logst(tremor)~location+log10(distance)+log10(charge), data=d.blast)
plregr(rr, xvar=FALSE)

## ----plresx, fig.width=8, fig.height=7.5---------------------------------
plresx(rr)

## ----plresx_trs, fig.width=8, fig.height=7.5-----------------------------
plresx(rr, transformed=TRUE)

## ----plres2x-------------------------------------------------------------
data(d.blast)
dd <- d.blast[as.numeric(d.blast$location)%in%c(1,3),]
rr <- lm(log10(tremor)~log10(distance)+log10(charge)+location, data=dd)
plres2x(~ log10(distance) + log10(charge), reg=rr, transformed=F,
        pcol=location)

## ----survresiduals-------------------------------------------------------
require(survival)
data(lung)
rr <- survreg(survival::Surv(time,status) ~ age+sex+wt.loss, data=lung)
plregr(rr, plotselect=c(default=0, resfit=1), xvar=FALSE, mf=c(1,1),
          smooth.sim=0)

## ----ordered-------------------------------------------------------------
cat("!!!")  

## ----resfitbin, figure.height=4------------------------------------------
  data(d.babysurvival)
  rr <- glm(Survival~Weight+Age+Apgar1,data=d.babysurvival,family=binomial)
  plmframes(1,2, mar=c(3,3,3,1))
  plregr(rr, plotselect=c(resfit=2, default=0), xvar=FALSE)
  plregr(rr, plotselect=c(resfit=2, default=0), condquant=FALSE, 
            xvar=FALSE)

## ----ploptions-----------------------------------------------------------
t.plopt <- ploptions(col="magenta", pch=3, smoothlines.lty=3)
plyx(Sepal.Width~Sepal.Length, data=iris)
## restore the old optios
ploptions(list=attr(t.plopt, "old"))

## ------------------------------------------------------------------------
op <- plmframes(1,3)
## plyx(Sepal.Width~Sepal.Length, data=iris, group=Species, mar=c(3,1,3,0))
par(attr(op, "oldpar"))
par("mfg")

## ----plyx_pattr----------------------------------------------------------
plyx(Sepal.Width~Sepal.Length, data=iris, 
     pch=Species, psize=Petal.Length, pcol=Species)

table(.plargs$pldata[,"(pch)"])

## ----varattributes-------------------------------------------------------
attr(iris$Sepal.Length, "ticksat") <- 
  structure(seq(4, 8, 0.5), small=seq(4,8,0.1))

plyx(Sepal.Width~Sepal.Length, data=iris, 
  gridlines=list(Sepal.Length=seq(4,8,0.5)))

## ----c.colors------------------------------------------------------------
ploptionsDefault$colors

